
#ifndef _C15_fi716_
#define _C15_fi716_

#ifdef __cplusplus
extern "C" {
#endif

extern EIF_BOOLEAN F561_2770(EIF_REFERENCE);
extern void EIF_Minit716(void);
extern EIF_INTEGER_32 F661_3248(EIF_REFERENCE);

#ifdef __cplusplus
}
#endif

#endif
